@@ -9,13 +9,13 @@ from .ecdf import ECDF
 from .estspec import smooth, periodogram, ar_periodogram
 from .kalman import Kalman
 from .lae import LAE
-from .linproc import LinearProcess
+from .arma import ARMA
 from .lqcontrol import LQ
 from .lss import LSS
+from .matrix_eqn import solve_discrete_lyapunov, solve_discrete_riccati
 from .mc_tools import DMarkov, mc_sample_path, mc_compute_stationary
 from .quadsums import var_quadratic_sum, m_quadratic_sum
 from .rank_nullspace import rank_est, nullspace
-from .riccati import dare
 from .robustlq import RBLQ
 from .tauchen import approx_markov
 from . import quad as quad
